@@ -13,11 +13,11 @@ import sklearn
 name_holder = {
     'LinearRegression' : 'Linear Regression',
     'Ridge' : "Ridge Regression",
-    'Lasso' : "Lasso",
+    'Lasso' : "Lasso Regression",
     'DecisionTreeRegressor' : 'Decision Tree Regressor',
     'RandomForestRegressor' : 'Random Forest Regressor',
     'AdaBoostRegressor' : 'AdaBoost Regressor',
-    'ExtraTreesRegressor' : 'ExtraTreesRegressor',
+    'ExtraTreesRegressor' : 'Extra Trees Regressor',
     'BaggingRegressor' : 'Bagging Regressor',
     'GradientBoostingRegressor' : 'Gradient Boosting Regressor',
     'LogisticRegression' : 'Logistic Regression',
@@ -45,6 +45,7 @@ column_holder={
     'r2':'R2 Score',
     'rmse':'RMSE',
     'mae':'MAE',
+    'accuracy':'Accuracy',
     'precision':'Precsion',
     'precision_micro':'Precsion Micro',
     'precision_macro':'Precison Macro',
@@ -54,7 +55,7 @@ column_holder={
     'f1':'F1 Score',
     'f1_micro':'F1 Score Micro',
     'f1_macro':'F1 Score Macro',
-    'Estimator':'Estimator'
+    'Estimator':'Estimator',
     'Feature Engineering Method':'Feature Engineering Method',
     'Hyperparameter Optimization Method':'Hyperparameter Optimization Method'
 }
@@ -75,7 +76,9 @@ def auto_ensemble(dataset, label, task, base_layer_models=None, meta_layer_model
             Returns:     
                     ensemble(model object) : trained super learner model   
     '''
-
+    if dataset.shape[0]>30000 or dataset.shape[1]>30:
+        max_evals=100
+        
     # Data Preprocessing
     prepocessed_dataset = preprocess_data(dataset, label, task)
     print('\nData Preprocessed.\n')
@@ -152,6 +155,9 @@ def automl_run(dataset, label, task, base_layer_models=None, meta_layer_models=N
     '''
 
     # Data Preprocessing
+    if dataset.shape[0]>30000 or dataset.shape[1]>30:
+        max_evals=100
+        
     prepocessed_dataset = preprocess_data(dataset, label, task)
 
     print('\nData Preprocessed.\n')
@@ -213,7 +219,8 @@ def automl_run(dataset, label, task, base_layer_models=None, meta_layer_models=N
                 stats = get_model_metrics(ensemble, feature_engineered_dataset[label], task, X_test, Y_test)
                 temp = [ensemble, name_holder[meta_layer_model]]
                 temp.append(', '.join([name_holder[model.__name__] for model in ensemble.models]))
-                temp.extend(list(stats.values()))
+                stats = list(map(lambda value : round(value, 4), stats.values()))
+                temp.extend(list(stats))
                 stats_list.append(temp)
 
     elif task == 'classification':
@@ -259,7 +266,8 @@ def automl_run(dataset, label, task, base_layer_models=None, meta_layer_models=N
                 temp = [ensemble, name_holder[meta_layer_model]]
                 temp.append(', '.join([name_holder[model.__name__] for model in ensemble.models]))
                 stats = list(map(lambda value : round(value, 4), stats.values()))
-                temp.extend(list(stats.values()))
+                print(stats)
+                temp.extend(list(stats))
                 stats_list.append(temp)
     
     print('\nEnsemble trained\n')
